// Example file for using archimedean_solids.inc
// Bill Pragnell 2009
//
// This file is licensed under the terms of the CC-LGPL
//
// -----------------------------------------------------------
//
// This file modified to use the POVRay patch implementation
// of the ObjectAsIso.inc technique for treating objects as
// isosurfaces.
//
// Please find the archimedean_solids.inc file at:
// http://lib.povray.org/searchcollection/index.php
//
//                                                WFP 09/14/09
// -----------------------------------------------------------

#include "archimedean_solids.inc"

global_settings {
 // assumed_gamma 1
 radiosity {
  pretrace_start 0.08
  pretrace_end 0.01
  error_bound 0.2
  count 150
  low_error_factor 0.5
  minimum_reuse 0.01
  recursion_limit 1
  nearest_count 4
  gray_threshold 0
  brightness 1 } }

camera {
 location <-5, 15, -10>
 up y
 right x
 angle 45
 look_at <0, 0, 0> }

   light_source {
    <100, 150, -25> color rgb 1
    area_light 20*x, 20*y, 6, 6 circular orient adaptive 1 jitter
    }

// -----
// Create an array of objects containing the plain faces polyhedra.
// -----
#declare Archimedeans = array[13];
#declare Archimedeans[0]  = object { Archimedean_truncated_tetrahedron_faces2(yes)       clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[1]  = object { Archimedean_cuboctahedron_faces2(yes)               clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[2]  = object { Archimedean_truncated_cube_faces2(yes)              clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[3]  = object { Archimedean_truncated_octahedron_faces2(yes)        clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[4]  = object { Archimedean_rhombicuboctahedron_faces2(yes)         clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[5]  = object { Archimedean_truncated_cuboctahedron_faces2(yes)     clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[6]  = object { Archimedean_snub_cuboctahedron_faces2(yes)          clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[7]  = object { Archimedean_icosidodecahedron_faces2(yes)           clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[8]  = object { Archimedean_truncated_dodecahedron_faces2(yes)      clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[9]  = object { Archimedean_truncated_icosahedron_faces2(yes)       clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[10] = object { Archimedean_rhombicosidodecahedron_faces2(yes)      clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[11] = object { Archimedean_truncated_icosidodecahedron_faces2(yes) clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }
#declare Archimedeans[12] = object { Archimedean_snub_icosidodecahedron_faces2(yes)      clipped_by{ box { <-1.2,-0.2,-1.2>,<1.2,2.2,1.2> }} bounded_by{ clipped_by } }

#declare ArchimedeansP = array[13];
#declare ArchimedeansP[0]  = function{pattern{object {Archimedeans[0]}}}
#declare ArchimedeansP[1]  = function{pattern{object {Archimedeans[1]}}}
#declare ArchimedeansP[2]  = function{pattern{object {Archimedeans[2]}}}
#declare ArchimedeansP[3]  = function{pattern{object {Archimedeans[3]}}}
#declare ArchimedeansP[4]  = function{pattern{object {Archimedeans[4]}}}
#declare ArchimedeansP[5]  = function{pattern{object {Archimedeans[5]}}}
#declare ArchimedeansP[6]  = function{pattern{object {Archimedeans[6]}}}
#declare ArchimedeansP[7]  = function{pattern{object {Archimedeans[7]}}}
#declare ArchimedeansP[8]  = function{pattern{object {Archimedeans[8]}}}
#declare ArchimedeansP[9]  = function{pattern{object {Archimedeans[9]}}}
#declare ArchimedeansP[10] = function{pattern{object {Archimedeans[10]}}}
#declare ArchimedeansP[11] = function{pattern{object {Archimedeans[11]}}}
#declare ArchimedeansP[12] = function{pattern{object {Archimedeans[12]}}}

#declare ArchimedeansAsIso = array[13];
#declare ArchimedeansAsIso[0]  = isosurface{function{0.100-ArchimedeansP[0](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[1]  = isosurface{function{0.100-ArchimedeansP[1](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[2]  = isosurface{function{0.100-ArchimedeansP[2](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[3]  = isosurface{function{0.100-ArchimedeansP[3](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[4]  = isosurface{function{0.100-ArchimedeansP[4](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[5]  = isosurface{function{0.100-ArchimedeansP[5](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[6]  = isosurface{function{0.100-ArchimedeansP[6](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[7]  = isosurface{function{0.100-ArchimedeansP[7](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[8]  = isosurface{function{0.100-ArchimedeansP[8](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[9]  = isosurface{function{0.100-ArchimedeansP[9](x,y,z) +(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[10] = isosurface{function{0.100-ArchimedeansP[10](x,y,z)+(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[11] = isosurface{function{0.100-ArchimedeansP[11](x,y,z)+(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }
#declare ArchimedeansAsIso[12] = isosurface{function{0.100-ArchimedeansP[12](x,y,z)+(f_noise3d(20*x,20*y,20*z)/4) } accuracy 0.0001 max_gradient 22 all_intersections contained_by {box{<-1.2,-0.2,-1.2>,2.2}} }

#declare Texture = array[13];
#declare Texture[0]  = texture { pigment { color rgb <1.00000,0.78824,0.00392> } }
#declare Texture[1]  = texture { pigment { color rgb <0.06667,0.04706,0.42353> } }
#declare Texture[2]  = texture { pigment { color rgb <0.40392,0.01176,0.17647> } }
#declare Texture[3]  = texture { pigment { color rgb <0.19608,0.48627,0.07843> } }
#declare Texture[4]  = texture { pigment { color rgb <0.68235,0.50196,0.61961> } }
#declare Texture[5]  = texture { pigment { color rgb <0.23137,0.56863,0.70588> } }
#declare Texture[6]  = texture { pigment { color rgb <0.34902,0.15686,0.01569> } }
#declare Texture[7]  = texture { pigment { color rgb <0.97255,0.72157,0.32549> } }
#declare Texture[8]  = texture { pigment { color rgb <0.96863,0.46667,0.01176> } }
#declare Texture[9]  = texture { pigment { color rgb <0.28235,0.10980,0.10980> } }
#declare Texture[10] = texture { pigment { color rgb <0.00000,0.20784,0.19608> } }
#declare Texture[11] = texture { pigment { color rgb <0.39216,0.37647,0.46667> } }
#declare Texture[12] = texture { pigment { color rgb <0.78039,0.01176,0.11765> } }


// -----
// Loop through arrays and place the polyhedra (faces+edges) in a circular pattern.
// -----
// Please note that the faces need to be vertically translated by R_Vertex so they line up
// with the edges.
// -----
#declare Ang = 0;
#declare Num = 0;
#while (Num < 13)
    object { ArchimedeansAsIso[Num] translate <0, 0.06, -5> rotate y*Ang texture { Texture[Num] } finish { ambient 0 } }
  //object { Archimedeans[Num]      translate <0, 0.06, -5> rotate y*Ang texture { Texture[Num] } finish { ambient 0 } }
    #declare Num = Num +  1;
    #declare Ang = Ang + 360/13;
#end

plane { y, 0 pigment { rgb 0.66 } finish { ambient 0 } }
background { rgb <0.1, 0.2, 0.25> }

// object { cylinder { <0,0,0>, <0,2.0,0>, 0.25 }
//          texture { pigment { color rgb <1.00000,0.78824,0.00392> } }
// }

